# qsense

qsense is an useful library and command line for qliksense

## installation

pip install qsense

## Useful commands

### export_remove_old_apps

qsense export_delete_old_apps qliksense.redaelli.org /home/matteo/certificates/qlik/client.pem  --target_path '/tmp' --modified_days=300 --last_reload_days=300
